.. image:: https://img.shields.io/travis/nengo/nengo_spa/master.svg
  :target: https://travis-ci.org/nengo/nengo_spa
  :alt: Travis-CI build status

.. image:: https://ci.appveyor.com/api/projects/status/5blofvbh8305w75g?svg=true
  :target: https://ci.appveyor.com/project/nengo/nengo_spa
  :alt: AppVeyor build status

.. image:: https://img.shields.io/codecov/c/github/nengo/nengo_spa/master.svg
  :target: https://codecov.io/gh/nengo/nengo_spa/branch/master
  :alt: Test coverage


************************************************************************
Nengo SPA: Implementation of the Semantic Pointer Architecture for Nengo
************************************************************************

Project status
==============

- All of the core functionality is implemented, but the API might still be
  subject to changes.
- The documentation needs extensive updates.
- The integration with the Nengo GUI is not implemented yet.

Installation
============

Nengo SPA depends on `Nengo 2.4+ <https://nengo.github.io/>`_, and we recommend
that you install Nengo before installing Nengo SPA.

To install Nengo SPA::

    pip install nengo_spa

Nengo SPA is tested to work on Python 2.7 and 3.4+.

Documentation
=============

TODO

Getting Help
============

Questions relating to Nengo and Nengo SPA, whether it's use or it's
development, should be asked on the Nengo forum at `<https://forum.nengo.ai>`_.
